Type Alias PathId
pub type PathId = [u64; 5];Expand description
Identifier for a path traversed using an allowed DestinationRouting
over the network.
pub type PathId = [u64; 5];Identifier for a path traversed using an allowed DestinationRouting
over the network.